@@ -355,6 +355,8 @@ class GTK_Main(object):
         interface.register_gui(self)
         self.pickle_file_conversion()
 
+        self.fullscreen = False
+
         self.recent_files = []
         self.progress_timer_id = None
         self.volume_timer_id = None
@@ -494,6 +496,7 @@ class GTK_Main(object):
             self.volume.connect('level_changed', self.volume_changed_hildon)
             self.volume.connect('mute_toggled', self.mute_toggled)
             window.connect('key-press-event', self.on_key_press)
+            window.connect('window-state-event', self.window_state_event)
             main_hbox.pack_start(self.volume, False, True)
 
             # Add a button to pop out the volume bar
@@ -700,6 +703,17 @@ class GTK_Main(object):
             self.forward_callback(self.forward_button)
         elif event.keyval == gtk.keysyms.Return: # play/pause
             self.on_btn_play_pause_clicked()
+        elif event.keyval == gtk.keysyms.F6: # fullscreen
+            if self.fullscreen:
+                self.main_window.unfullscreen()
+            else:
+                self.main_window.fullscreen()
+
+    def window_state_event(self, widget, event):
+        if event.new_window_state & gtk.gdk.WINDOW_STATE_FULLSCREEN:
+            self.fullscreen = True
+        else:
+            self.fullscreen = False
 
     # The following two functions get and set the
     #   volume from the volume control widgets.
